@@ -38,49 +38,7 @@ mcmc_diagnostics.dynamitefit <- function(x, n = 3L) {
     "Argument {.arg n} must be a single {.cls integer}."
   )
   if (!is.null(x$stanfit)) {
-    if (identical(x$stanfit@stan_args[[1L]]$algorithm, "NUTS")) {
-      n_draws <- ndraws(x)
-      n_divs <- rstan::get_num_divergent(x$stanfit)
-      n_trees <- rstan::get_num_max_treedepth(x$stanfit)
-      bfmis <- rstan::get_bfmi(x$stanfit)
-      all_ok <- n_divs == 0L && n_trees == 0L && all(bfmis > 0.2)
-      cat("NUTS sampler diagnostics:\n")
-      all_ok_str <- ifelse_(
-        all_ok,
-        "\nNo divergences, saturated max treedepths or low E-BFMIs.\n",
-        ""
-      )
-      cat(all_ok_str)
-      div_str <- ifelse_(
-        n_divs > 0L,
-        paste0(
-          "\n", n_divs, " out of ", n_draws, " iterations ended with a ",
-          "divergence. See Stan documentation for details.\n"
-        ),
-        ""
-      )
-      cat(div_str)
-      mt <- x$stanfit@stan_args[[1L]]$control$max_treedepth
-      mt <- ifelse_(is.null(mt), 10, mt)
-      trees_str <- ifelse_(
-        n_trees > 0L,
-        paste0(
-          "\n", n_trees, " out of ", n_draws, " saturated the maximum ",
-          "tree depth of ", mt, ". See Stan documentation for details.\n"
-        ),
-        ""
-      )
-      cat(trees_str)
-      bfmis_str <- ifelse_(
-        any(bfmis < 0.2),
-        paste0(
-          "\nChain(s) ", cs(which(bfmis < 0.2)), " had E-BFMI below 0.2, ",
-          "indicating possible issues. See Stan documentation for details.\n"
-        ),
-        ""
-      )
-      cat(bfmis_str)
-    }
+    hmc_diagnostics(x)
     init <- seq_len(n)
     sumr <- posterior::summarise_draws(
       suppressWarnings(as_draws(x)),
@@ -106,3 +64,53 @@ mcmc_diagnostics.dynamitefit <- function(x, n = 3L) {
   }
   invisible(x)
 }
+
+#' HMC Diagnostics for a Dynamite Model
+#'
+#' Prints the divergences, saturated treedepths, and low E-BFMI warnings
+#' @noRd
+hmc_diagnostics <- function(x) {
+  if (x$stanfit@stan_args[[1L]]$algorithm %in% c("NUTS", "hmc")) {
+    n_draws <- ndraws(x)
+    n_divs <- rstan::get_num_divergent(x$stanfit)
+    n_trees <- rstan::get_num_max_treedepth(x$stanfit)
+    bfmis <- rstan::get_bfmi(x$stanfit)
+    all_ok <- n_divs == 0L && n_trees == 0L && all(bfmis > 0.2)
+    cat("NUTS sampler diagnostics:\n")
+    all_ok_str <- ifelse_(
+      all_ok,
+      "\nNo divergences, saturated max treedepths or low E-BFMIs.\n",
+      ""
+    )
+    cat(all_ok_str)
+    div_str <- ifelse_(
+      n_divs > 0L,
+      paste0(
+        "\n", n_divs, " out of ", n_draws, " iterations ended with a ",
+        "divergence. See Stan documentation for details.\n"
+      ),
+      ""
+    )
+    cat(div_str)
+    mt <- x$stanfit@stan_args[[1L]]$control$max_treedepth
+    mt <- ifelse_(is.null(mt), 10, mt)
+    trees_str <- ifelse_(
+      n_trees > 0L,
+      paste0(
+        "\n", n_trees, " out of ", n_draws, " saturated the maximum ",
+        "tree depth of ", mt, ". See Stan documentation for details.\n"
+      ),
+      ""
+    )
+    cat(trees_str)
+    bfmis_str <- ifelse_(
+      any(bfmis < 0.2),
+      paste0(
+        "\nChain(s) ", cs(which(bfmis < 0.2)), " had E-BFMI below 0.2, ",
+        "indicating possible issues. See Stan documentation for details.\n"
+      ),
+      ""
+    )
+    cat(bfmis_str)
+  }
+}
